"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
const utils_1 = require("../../utils");
class Create extends command_1.default {
    async run() {
        const { flags } = await this.parse(Create);
        const pipeString = utils_1.safeStdinRead();
        const { teamPath } = flags;
        const options = {
            title: flags.title,
            content: pipeString || flags.content,
            readPermission: flags.readPermission,
            writePermission: flags.writePermission,
            commentPermission: flags.commentPermission
        };
        if (!teamPath) {
            this.error('Flag teamPath could not be empty');
        }
        try {
            const APIClient = await this.getAPIClient();
            const note = await APIClient.createTeamNote(teamPath, options);
            core_1.CliUx.ux.table([note], {
                id: {
                    header: 'ID',
                },
                title: {},
                userPath: {
                    header: 'User path'
                },
                teamPath: {
                    header: 'Team path'
                }
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (e) {
            this.log('Create team note failed');
            this.error(e);
        }
    }
}
exports.default = Create;
Create.description = 'Create a team note';
Create.examples = [
    `team-notes:create --teamPath=CLI-test --content='# A new note' --readPermission=owner --writePermission=owner --commentPermission=disabled
ID                     Title                            User Path              Team Path
────────────────────── ──────────────────────────────── ────────────────────── ────────
raUuSTetT5uQbqQfLnz9lA A new note                       gvfz2UB5THiKABQJQnLs6Q null     `,
    'Or you can pipe content via Unix pipeline:',
    'cat README.md | hackmd-cli notes create --teamPath=CLI-test'
];
Create.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }), teamPath: flags_1.teamPath(), title: flags_1.noteTitle(), content: flags_1.noteContent(), readPermission: flags_1.notePermission(), writePermission: flags_1.notePermission(), commentPermission: flags_1.commentPermission() }, core_1.CliUx.ux.table.flags());
